@@ -30,6 +30,7 @@ from ..helpers import getLogger
 # Gets the instance of the logger.
 logSys = getLogger(__name__)
 
+
 class Fail2banReader(ConfigReader):
 	
 	def __init__(self, **kwargs):
@@ -46,21 +47,20 @@ class Fail2banReader(ConfigReader):
 	def getOptions(self):
 		opts = [["string", "loglevel", "INFO" ],
 				["string", "logtarget", "STDERR"],
+				["string", "syslogsocket", "auto"],
 				["string", "dbfile", "/var/lib/fail2ban/fail2ban.sqlite3"],
 				["int", "dbpurgeage", 86400]]
 		self.__opts = ConfigReader.getOptions(self, "Definition", opts)
 	
 	def convert(self):
+		# Ensure logtarget/level set first so any db errors are captured
+		# Also dbfile should be set before all other database options.
+		# So adding order indices into items, to be stripped after sorting, upon return
+		order = {"syslogsocket":0, "loglevel":1, "logtarget":2,
+			"dbfile":50, "dbpurgeage":51}
 		stream = list()
 		for opt in self.__opts:
-			if opt == "loglevel":
-				stream.append(["set", "loglevel", self.__opts[opt]])
-			elif opt == "logtarget":
-				stream.append(["set", "logtarget", self.__opts[opt]])
-			elif opt == "dbfile":
-				stream.append(["set", "dbfile", self.__opts[opt]])
-			elif opt == "dbpurgeage":
-				stream.append(["set", "dbpurgeage", self.__opts[opt]])
-		# Ensure logtarget/level set first so any db errors are captured
-		return sorted(stream, reverse=True)
+			if opt in order:
+				stream.append((order[opt], ["set", opt, self.__opts[opt]]))
+		return [opt[1] for opt in sorted(stream)]
 	
