@@ -23,7 +23,8 @@ __author__ = "Cyril Jaquier, Yaroslav Halchenko"
 __copyright__ = "Copyright (c) 2004 Cyril Jaquier, 2012 Yaroslav Halchenko"
 __license__ = "GPL"
 
-import time, fcntl
+import fcntl
+import time
 
 import gamin
 
@@ -35,6 +36,7 @@ from ..helpers import getLogger
 # Gets the instance of the logger.
 logSys = getLogger(__name__)
 
+
 ##
 # Log reader class.
 #
@@ -60,16 +62,14 @@ class FilterGamin(FileFilter):
 		fcntl.fcntl(fd, fcntl.F_SETFD, flags|fcntl.FD_CLOEXEC)
 		logSys.debug("Created FilterGamin")
 
-
 	def callback(self, path, event):
-		logSys.debug("Got event: " + `event` + " for " + path)
+		logSys.debug("Got event: " + repr(event) + " for " + path)
 		if event in (gamin.GAMCreated, gamin.GAMChanged, gamin.GAMExists):
 			logSys.debug("File changed: " + path)
 			self.__modified = True
 
 		self._process_file(path)
 
-
 	def _process_file(self, path):
 		"""Process a given file
 
@@ -121,7 +121,6 @@ class FilterGamin(FileFilter):
 		logSys.debug(self.jail.name + ": filter terminated")
 		return True
 
-
 	def stop(self):
 		super(FilterGamin, self).stop()
 		self.__cleanup()
