@@ -21,7 +21,9 @@ __author__ = "Cyril Jaquier"
 __copyright__ = "Copyright (c) 2004 Cyril Jaquier"
 __license__ = "GPL"
 
-import time, datetime
+import datetime
+import time
+
 
 ##
 # MyTime class.
