@@ -55,64 +55,69 @@ class HelpersTest(unittest.TestCase):
 			# might be fragile due to ' vs "
 			self.assertEqual(args, "('Very bad', None)")
 
-# based on
-# http://stackoverflow.com/questions/2186525/use-a-glob-to-find-files-recursively-in-python
-def recursive_glob(treeroot, pattern):
-	results = []
-	for base, dirs, files in os.walk(treeroot):
-		goodfiles = fnmatch.filter(dirs + files, pattern)
-		results.extend(os.path.join(base, f) for f in goodfiles)
-	return results
 
 class SetupTest(unittest.TestCase):
 
 	def setUp(self):
-		setup = os.path.join(os.path.dirname(__file__), '..', 'setup.py')
+		setup = os.path.join(os.path.dirname(__file__), '..', '..', 'setup.py')
 		self.setup = os.path.exists(setup) and setup or None
-		if not self.setup and sys.version_info >= (2,7): # running not out of the source
+		if not self.setup and sys.version_info >= (2,7): # pragma: no cover - running not out of the source
 			raise unittest.SkipTest(
 				"Seems to be running not out of source distribution"
 				" -- cannot locate setup.py")
 
 	def testSetupInstallRoot(self):
-		if not self.setup: return			  # if verbose skip didn't work out
+		if not self.setup:
+			return			  # if verbose skip didn't work out
 		tmp = tempfile.mkdtemp()
-		os.system("%s %s install --root=%s >/dev/null"
-				  % (sys.executable, self.setup, tmp))
+		try:
+			os.system("%s %s install --root=%s >/dev/null"
+					  % (sys.executable, self.setup, tmp))
 
-		def addpath(l):
-			return [os.path.join(tmp, x) for x in l]
+			def strippath(l):
+				return [x[len(tmp)+1:] for x in l]
 
-		def strippath(l):
-			return [x[len(tmp)+1:] for x in l]
+			got = strippath(sorted(glob('%s/*' % tmp)))
+			need = ['etc', 'usr', 'var']
 
-		got = strippath(sorted(glob('%s/*' % tmp)))
-		need = ['etc', 'usr', 'var']
+			# if anything is missing
+			if set(need).difference(got): # pragma: no cover
+				#  below code was actually to print out not missing but
+				#  rather files in 'excess'.  Left in place in case we
+				#  decide to revert to such more strict test
 
-		# if anything is missing
-		if set(need).difference(got):
-			#  below code was actually to print out not missing but
-			#  rather files in 'excess'.  Left in place in case we
-			#  decide to revert to such more strict test
-			files = {}
-			for missing in set(got).difference(need):
-				missing_full = os.path.join(tmp, missing)
-				files[missing] = os.path.exists(missing_full) \
-					and strippath(recursive_glob(missing_full, '*')) or None
+				# based on
+				# http://stackoverflow.com/questions/2186525/use-a-glob-to-find-files-recursively-in-python
+				def recursive_glob(treeroot, pattern):
+					results = []
+					for base, dirs, files in os.walk(treeroot):
+						goodfiles = fnmatch.filter(dirs + files, pattern)
+						results.extend(os.path.join(base, f) for f in goodfiles)
+					return results
 
-			self.assertEqual(
-				got, need,
-				msg="Got: %s Needed: %s under %s. Files under new paths: %s"
-				% (got, need, tmp, files))
+				files = {}
+				for missing in set(got).difference(need):
+					missing_full = os.path.join(tmp, missing)
+					files[missing] = os.path.exists(missing_full) \
+						and strippath(recursive_glob(missing_full, '*')) or None
 
-		# Assure presence of some files we expect to see in the installation
-		for f in ('etc/fail2ban/fail2ban.conf',
-				  'etc/fail2ban/jail.conf'):
-			self.assertTrue(os.path.exists(os.path.join(tmp, f)),
-							msg="Can't find %s" % f)
+				self.assertEqual(
+					got, need,
+					msg="Got: %s Needed: %s under %s. Files under new paths: %s"
+					% (got, need, tmp, files))
+
+			# Assure presence of some files we expect to see in the installation
+			for f in ('etc/fail2ban/fail2ban.conf',
+					  'etc/fail2ban/jail.conf'):
+				self.assertTrue(os.path.exists(os.path.join(tmp, f)),
+								msg="Can't find %s" % f)
+		finally:
+			# clean up
+			shutil.rmtree(tmp)
+			# remove build directory
+			os.system("%s %s clean --all >/dev/null 2>&1"
+					  % (sys.executable, self.setup))
 
-		# clean up
-		shutil.rmtree(tmp)
 
 class TestsUtilsTest(unittest.TestCase):
 
@@ -134,8 +139,10 @@ class TestsUtilsTest(unittest.TestCase):
 				raise ValueError()
 
 			def deep_function(i):
-				if i: deep_function(i-1)
-				else: func_raise()
+				if i:
+					deep_function(i-1)
+				else:
+					func_raise()
 
 			try:
 				print deep_function(3)
@@ -148,10 +155,11 @@ class TestsUtilsTest(unittest.TestCase):
 				# we must be calling it from setup or nosetests but using at least
 				# nose's core etc
 				self.assertTrue('>' in s, msg="no '>' in %r" % s)
-			else:
-				self.assertFalse('>' in s, msg="'>' present in %r" % s)  # There is only "fail2ban-testcases" in this case, no true traceback
-			self.assertTrue(':' in s, msg="no ':' in %r" % s)
+			elif not ('coverage' in s):
+				# There is only "fail2ban-testcases" in this case, no true traceback
+				self.assertFalse('>' in s, msg="'>' present in %r" % s)
 
+			self.assertTrue(':' in s, msg="no ':' in %r" % s)
 
 	def testFormatterWithTraceBack(self):
 		strout = StringIO()
@@ -175,6 +183,7 @@ class TestsUtilsTest(unittest.TestCase):
 
 iso8601 = DatePatternRegex("%Y-%m-%d[T ]%H:%M:%S(?:\.%f)?%z")
 
+
 class CustomDateFormatsTest(unittest.TestCase):
 
 	def testIso8601(self):
