@@ -22,16 +22,22 @@
 __copyright__ = "Copyright (c) 2013 Steven Hiscocks"
 __license__ = "GPL"
 
-import unittest, sys, os, fileinput, re, time, datetime, inspect
-
+import datetime
+import fileinput
+import inspect
 import json
-
+import os
+import re
+import sys
+import time
+import unittest
 from ..server.filter import Filter
 from ..client.filterreader import FilterReader
 from .utils import setUpMyTime, tearDownMyTime, CONFIG_DIR
 
 TEST_FILES_DIR = os.path.join(os.path.dirname(__file__), "files")
 
+
 class FilterSamplesRegex(unittest.TestCase):
 
 	def setUp(self):
@@ -53,6 +59,7 @@ class FilterSamplesRegex(unittest.TestCase):
 			>= 10,
 			"Expected more FilterSampleRegexs tests")
 
+
 def testSampleRegexsFactory(name):
 	def testFilter(self):
 
@@ -120,7 +127,6 @@ def testSampleRegexsFactory(name):
 				except ValueError:
 					jsonTimeLocal =	datetime.datetime.strptime(t, "%Y-%m-%dT%H:%M:%S.%f")
 
-
 				jsonTime = time.mktime(jsonTimeLocal.timetuple())
 				
 				jsonTime += jsonTimeLocal.microsecond / 1000000
@@ -141,7 +147,8 @@ def testSampleRegexsFactory(name):
 
 	return testFilter
 
-for filter_ in filter(lambda x: not x.endswith('common.conf'), os.listdir(os.path.join(CONFIG_DIR, "filter.d"))):
+for filter_ in filter(lambda x: not x.endswith('common.conf') and x.endswith('.conf'),
+					  os.listdir(os.path.join(CONFIG_DIR, "filter.d"))):
 	filterName = filter_.rpartition(".")[0]
 	if not filterName.startswith('.'):
 		setattr(
